# Seki

[![PyPI version](https://badge.fury.io/py/seki.svg)](https://badge.fury.io/py/seki)
[![Known Vulnerabilities](https://snyk.io/test/github/oscarbc96/seki/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/oscarbc96/seki?targetFile=requirements.txt)

Automated security tools made easy.
